drop_cols_all_na: Remove columns with missing values
Description
Remove columns of a table whose values are all NA or who have any NA
Usage
drop_cols_all_na(.tbl)drop_cols_any_na(.tbl)
drop_na_cols(.tbl)
Value
An object of the same class as data with cols containing all
NA values removed
Details
drop_cols_all_na removes all cols whose only values are NA.
drop_cols_any_na removes columns that have any NA. They work on all
table-like objects.